%define target msp430

Name:		%{target}-gcc
Version:	4.6.4
Release:	5%{?dist}
Summary:	Cross Compiling GNU GCC targeted at %{target}
Group:		Development/Languages
License:	GPLv2+
URL:		http://mspgcc.sf.net/
Source0:	ftp://ftp.gnu.org/gnu/gcc/gcc-%{version}/gcc-core-%{version}.tar.bz2

# Patch from mspgcc project
# This is actually against 4.6.3, but in order to build we need some fixes
# that are in 4.6.4
Patch0:		msp430-gcc-4.6.3-20120406.patch
Patch1:		msp430-gcc-4.6.4-host-aarch64.patch

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

# We need the uniarch variant of binutils
# which was shipped as 2.21.1a-1 in Fedora
BuildRequires:	%{target}-binutils >= 2.21.1a-1
BuildRequires:	gmp-devel, mpfr-devel, libmpc-devel
Requires:	%{target}-binutils >= 2.21.1a-1
Provides: 	bundled(libiberty)

%description
This is a cross compiling version of GNU GCC, which can be used to
compile for the %{target} platform, instead of for the native %{_arch} 
platform.

%prep
%setup -q -c -n msp430-gcc
pushd gcc-%{version}
%patch0 -p1
%patch1 -p1
popd

# Extract %%__os_install_post into os_install_post~
cat << \EOF > os_install_post~
%__os_install_post
EOF

# Generate customized brp-*scripts
cat os_install_post~ | while read a x y; do
case $a in
# Prevent brp-strip* from trying to handle foreign binaries
*/brp-strip*)
  b=$(basename $a)
  sed -e 's,find $RPM_BUILD_ROOT,find $RPM_BUILD_ROOT%_bindir $RPM_BUILD_ROOT%_libexecdir,' $a > $b
  chmod a+x $b
  ;;
esac
done

sed -e 's,^[ ]*/usr/lib/rpm.*/brp-strip,./brp-strip,' \
< os_install_post~ > os_install_post 


%build
mkdir gcc-%{version}-build
cd gcc-%{version}-build
CC="%{__cc} ${RPM_OPT_FLAGS}" ../gcc-%{version}/configure --prefix=%{_prefix} --mandir=%{_mandir} \
	--infodir=%{_infodir} --target=%{target} --disable-nls \
	--libdir=%{_libdir} --enable-version-specific-runtime-libs \
	--enable-languages=c
# Building GCC-3.2.3 is not smp-safe
make


%install
rm -rf $RPM_BUILD_ROOT
make -C gcc-%{version}-build install DESTDIR=$RPM_BUILD_ROOT

# we don't want these as we are a cross version
rm -rf $RPM_BUILD_ROOT%{_infodir}
rm -rf $RPM_BUILD_ROOT%{_mandir}/man7
rm -f $RPM_BUILD_ROOT%{_libdir}/libiberty.a

%define __os_install_post . ./os_install_post


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%dir %{_libdir}/gcc
%dir %{_libdir}/gcc/%{target}/
%dir %{_libdir}/gcc/%{target}/%{version}/
%dir %{_libdir}/gcc/%{target}/mcpu-430x
%dir %{_libdir}/gcc/%{target}/mmpy-16
%dir %{_libexecdir}/gcc/%{target}/%{version}

%{_bindir}/%{target}-*
%{_libdir}/gcc/%{target}/%{version}/*
%{_mandir}/man1/%{target}-*.1.gz
%{_libexecdir}/gcc/%{target}/%{version}/*


%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jun 26 2014 Yaakov Selkowitz <yselkowi@redhat.com> - 4.6.4-3
- Fix FTBFS on aarch64 host (#926177)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Dec 27 2013 Rob Spanton <rspanton@zepler.net> 4.6.4-1
- Update to 4.6.4 to fix build

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.6.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Oct 15 2012 Jon Ciesla <limburgher@gmail.com> 4.6.3-2
- Provides: bundled(libiberty)

* Sat Sep 08 2012 Rob Spanton <rspanton@zepler.net> 4.6.3-1
- Update to mspgcc uniarch LTS release

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.3-7.20100805cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.3-6.20100805cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.3-5.20100805cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Aug 5 2010 Rob Spanton <rspanton@zepler.net> 3.2.3-4.20100805cvs
- Fix the release number to make version comparison work!

* Thu Aug 5 2010 Rob Spanton <rspanton@zepler.net> 3.2.3-1.20100805cvs
- Bump up to latest CVS (adds support for a few more MSPs)

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2.3-3.20090210cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Feb 21 2009 Rob Spanton <rspanton@zepler.net> 3.2.3-2.20090210cvs
- Use setup macro to do cleaner decompressing.
- Own libdir/gcc-lib dirs.
- Rename man files rather than delete them.

* Tue Feb 10 2009 Rob Spanton <rspanton@zepler.net> 3.2.3-1.20090210cvs 
- Initial release

